@@ -240,10 +240,11 @@ Returns a TAG string which is assigned to the COMAND."
       (setq cmdstr (concat tag " "))
       ;; (erase-buffer) No need.
       (goto-char (point-min))
-      (if (elmo-imap4-response-bye-p elmo-imap4-current-response)
-	  (signal 'elmo-imap4-bye-error
-		  (list (elmo-imap4-response-error-text
-			 elmo-imap4-current-response))))
+      (when (elmo-imap4-response-bye-p elmo-imap4-current-response)
+	(elmo-network-close-session session)
+	(signal 'elmo-imap4-bye-error
+		(list (elmo-imap4-response-error-text
+		       elmo-imap4-current-response))))
       (setq elmo-imap4-current-response nil)
       (if elmo-imap4-parsing
 	  (error "IMAP process is running. Please wait (or plug again.)"))
@@ -355,8 +356,10 @@ If response is not `OK' response, causes error with IMAP response text."
     (if (elmo-imap4-response-ok-p response)
 	response
       (if (elmo-imap4-response-bye-p response)
-	  (signal 'elmo-imap4-bye-error
-		  (list (elmo-imap4-response-error-text response)))
+	  (progn
+	    (elmo-network-close-session session)
+	    (signal 'elmo-imap4-bye-error
+		    (list (elmo-imap4-response-error-text response))))
 	(error "IMAP error: %s"
 	       (or (elmo-imap4-response-error-text response)
 		   "No `OK' response from server."))))))
@@ -1474,20 +1477,20 @@ If optional argument UNMARK is non-nil, unmark."
 
 (defun elmo-imap4-append-msg (spec string &optional msg no-see)
   (let ((session (elmo-imap4-get-session spec))
-	send-buf)
+	send-buf result)
     (elmo-imap4-session-select-mailbox session
 				       (elmo-imap4-spec-mailbox spec))
     (setq send-buf (elmo-imap4-setup-send-buffer string))
     (unwind-protect
-	(elmo-imap4-send-command-wait
-	 session
-	 (list
-	  "append "
-	  (elmo-imap4-mailbox (elmo-imap4-spec-mailbox spec))
-	  (if no-see " " " (\\Seen) ")
-	  (elmo-imap4-buffer-literal send-buf)))
-      (kill-buffer send-buf)))
-  t)
+	(setq result (elmo-imap4-send-command-wait
+		      session
+		      (list
+		       "append "
+		       (elmo-imap4-mailbox (elmo-imap4-spec-mailbox spec))
+		       (if no-see " " " (\\Seen) ")
+		       (elmo-imap4-buffer-literal send-buf))))
+      (kill-buffer send-buf))
+    result))
 
 (defun elmo-imap4-copy-msgs (dst-spec
 			     msgs src-spec &optional expunge-it same-number)
@@ -1602,7 +1605,7 @@ Return nil if no complete line has arrived."
 		       (> (string-to-number (match-string 1))
 			  (min elmo-display-retrieval-progress-threshold 100)))
 		  (elmo-display-progress
-		   'elmo-display-retrieval-progress
+		   'elmo-imap4-display-literal-progress
 		   (format "Retrieving (%d/%d bytes)..."
 			   (- (point-max) (point))
 			   (string-to-number (match-string 1)))
