@@ -193,6 +193,8 @@ Don't cache if nil.")
       (setq elmo-nntp-read-point (point))
       (or (elmo-nntp-read-response session t)
 	  (error "Cannot open network"))
+      (if elmo-nntp-send-mode-reader
+	  (elmo-nntp-send-mode-reader session))
       (when (eq (elmo-network-stream-type-symbol
 		 (elmo-network-session-stream-type-internal session))
 		'starttls)
@@ -220,8 +222,6 @@ Don't cache if nil.")
 
 (luna-define-method elmo-network-setup-session ((session
 						 elmo-nntp-session))
-  (if elmo-nntp-send-mode-reader
-      (elmo-nntp-send-mode-reader session))
   (run-hooks 'elmo-nntp-opened-hook))
 
 (defun elmo-nntp-process-filter (process output)
@@ -889,7 +889,9 @@ Don't cache if nil.")
   (let ((session (elmo-nntp-get-session
 		  (list 'nntp nil elmo-default-nntp-user
 			hostname elmo-default-nntp-port
-			elmo-default-nntp-stream-type)))
+			(elmo-get-network-stream-type
+			 elmo-default-nntp-stream-type
+			 elmo-network-stream-type-alist))))
 	response has-message-id)
     (save-excursion
       (set-buffer content-buf)
