@@ -32,6 +32,8 @@
 (require 'elmo-vars)
 (require 'elmo-date)
 (eval-when-compile (require 'cl))
+(require 'mcharset)
+(require 'pces)
 (require 'std11)
 (require 'eword-decode)
 (require 'utf7)
@@ -508,7 +510,7 @@ File content is encoded with MIME-CHARSET."
 				   "Since" "Before" "ToCc"
 				   "!From" "!Subject" "!To" "!Cc" "!Body"
 				   "!Since" "!Before" "!ToCc")
-				 elmo-msgdb-extra-fields)) nil t))
+				 elmo-msgdb-extra-fields))))
 	 value)
     (setq field (if (string= field "")
 		    (setq field default)
@@ -1339,20 +1341,25 @@ Otherwise treat \\ in NEWTEXT string as special:
 	(setq result (not result)))
     result))
 
-(defun elmo-condition-find-key-internal (condition key)
+(defun elmo-condition-in-msgdb-p-internal (condition fields)
   (cond
    ((vectorp condition)
-    (if (string= (elmo-filter-key condition) key)
+    (if (not (member (elmo-filter-key condition) fields))
 	(throw 'found t)))
    ((or (eq (car condition) 'and)
 	(eq (car condition) 'or))
-    (elmo-condition-find-key-internal (nth 1 condition) key)
-    (elmo-condition-find-key-internal (nth 2 condition) key))))
-
-(defun elmo-condition-find-key (condition key)
-  (catch 'found
-    (elmo-condition-find-key-internal condition key)))
+    (elmo-condition-in-msgdb-p-internal (nth 1 condition) fields)
+    (elmo-condition-in-msgdb-p-internal (nth 2 condition) fields))))
 
+(defun elmo-condition-in-msgdb-p (condition)
+  (not (catch 'found
+	 (elmo-condition-in-msgdb-p-internal condition
+					     (append
+					      elmo-msgdb-extra-fields
+					      '("last" "first" "from"
+						"subject" "to" "cc" "since"
+						"before"))))))
+ 
 (defun elmo-buffer-field-condition-match (condition number number-list)
   (cond
    ((vectorp condition)
@@ -1642,6 +1649,14 @@ the value of `foo'."
     (defalias 'elmo-field-body 'std11-fetch-field) ;;no narrow-to-region
   (defalias 'elmo-field-body 'std11-field-body))
 
+(defun elmo-address-quote-specials (word)
+  "Make quoted string of WORD if needed."
+  (let ((lal (std11-lexical-analyze word)))
+    (if (or (assq 'specials lal)
+	    (assq 'domain-literal lal))
+	(prin1-to-string word)
+      word)))
+
 (defmacro elmo-string (string)
   "STRING without text property."
   (` (let ((obj (copy-sequence (, string))))
