@@ -104,7 +104,7 @@ If level 3 is required for uniqness with other candidates,
 (defun wl-ldap-make-filter (pat type-list)
   "Make RFC1558 quiery filter for PAT from ATTR-LIST.
 Each are \"OR\" combination, and PAT is beginning-match."
-  (concat "(&(objectclass=person)(|"
+  (concat "(&(objectclass=" wl-ldap-objectclass ")(|"
 	  (mapconcat (lambda (x) (format "(%s=%s*)" x pat)) ; fixed format
 		     type-list
 		     "")
@@ -280,13 +280,7 @@ Matched address lists are append to CL."
 	(completing-read "To: " cl)
       (read-string "To: "))))
 
-(defconst wl-address-specials-regexp "[]\"(),.:;<>@[\\]")
-
-(defun wl-address-quote-specials (word)
-  "Make quoted string of WORD if needed."
-  (if (string-match wl-address-specials-regexp word)
-      (prin1-to-string word)
-    word))
+(defalias 'wl-address-quote-specials 'elmo-address-quote-specials)
 
 (defun wl-address-make-completion-list (address-list)
   (let (addr-tuple cl)
