@@ -100,7 +100,7 @@
 			     wl-smtp-authenticate-type
 			   (list wl-smtp-authenticate-type)))))
 	    (smtp-use-sasl (and smtp-sasl-mechanisms t))
-	    (smtp-use-starttls wl-smtp-connection-type)
+	    (smtp-use-starttls (eq wl-smtp-connection-type 'starttls))
 	    smtp-sasl-user-name smtp-sasl-properties sasl-read-passphrase)
        (if (and (string= (car smtp-sasl-mechanisms) "DIGEST-MD5")
 		;; sendmail bug?
@@ -436,7 +436,7 @@ Reply to author if WITH-ARG is non-nil."
       (goto-char (point-min))
       (wl-draft-delete-fields ignored-fields))
     (goto-char (point-max))
-    (push-mark)
+    (push-mark (point) nil t)
     (goto-char (point-min)))
   (let ((beg (point)))
     (cond (mail-citation-hook (run-hooks 'mail-citation-hook))
@@ -472,6 +472,7 @@ Reply to author if WITH-ARG is non-nil."
 (defun wl-message-mail-p ()
   "If exist To, Cc or Bcc field, return non-nil."
   (or (wl-message-field-exists-p "To")
+      (wl-message-field-exists-p "Resent-to")      
       (wl-message-field-exists-p "Cc")
       (wl-message-field-exists-p "Bcc")
 ;;; This may be needed..
@@ -1088,14 +1089,14 @@ If FORCE-MSGID, ignore 'wl-insert-message-id'."
 
 (defun wl-draft-send (&optional kill-when-done mes-string)
   "Send current draft message.
-If optional argument is non-nil, current draft buffer is killed"
+If KILL-WHEN-DONE is non-nil, current draft buffer is killed"
   (interactive)
   ;; Don't call this explicitly.
   ;; Added to 'wl-draft-send-hook (by teranisi)
   ;; (wl-draft-config-exec)
   (run-hooks 'wl-draft-send-hook)
   (when (or (not wl-interactive-send)
-	    (y-or-n-p "Send current draft. OK?"))
+	    (y-or-n-p "Do you really want to send current draft? "))
     (let ((send-mail-function 'wl-draft-raw-send)
 	  (editing-buffer (current-buffer))
 	  (sending-buffer (wl-draft-generate-clone-buffer
@@ -1287,7 +1288,8 @@ If optional argument is non-nil, current draft buffer is killed"
   (unless (featurep 'wl)
     (require 'wl))
   (unless wl-init
-    (wl-load-profile))
+    (wl-load-profile)
+    (wl-plugged-init t))
   (wl-init 'wl-draft) ;; returns immediately if already initialized.
   (if (interactive-p)
       (setq summary-buf (wl-summary-get-buffer wl-summary-buffer-folder-name)))
@@ -1318,6 +1320,9 @@ If optional argument is non-nil, current draft buffer is killed"
 	(delete-other-windows))
     (auto-save-mode -1)
     (wl-draft-mode)
+    (make-local-variable 'truncate-partial-width-windows)
+    (setq truncate-partial-width-windows nil)
+    (setq truncate-lines wl-draft-truncate-lines)
     (setq wl-sent-message-via nil)
     (if (stringp (or from wl-from))
 	(insert "From: " (or from wl-from) "\n"))
@@ -1379,9 +1384,6 @@ If optional argument is non-nil, current draft buffer is killed"
 			   (1- (point)))
 			 'category 'mail-header-separator)
       (and body (insert body)))
-    (if wl-on-nemacs
-	(push-mark (point) t)
-      (push-mark (point) t t))
     (as-binary-output-file
      (write-region (point-min)(point-max) wl-draft-buffer-file-name
 		   nil t))
@@ -1485,9 +1487,6 @@ If optional argument is non-nil, current draft buffer is killed"
     (goto-char (point-min))
     (or (re-search-forward "\n\n" nil t)
 	(search-forward (concat mail-header-separator "\n") nil t))
-    (if wl-on-nemacs
-	(push-mark (point) t)
-      (push-mark (point) t t))
     (write-region (point-min)(point-max) wl-draft-buffer-file-name
 		  nil t)
     (wl-draft-overload-functions)
