@@ -843,11 +843,10 @@ This function is imported from Emacs 20.7."
 
 (defun wl-biff-check-folder (folder)
   (if (eq (elmo-folder-get-type folder) 'pop3)
-      ;; pop3 biff should share the session.
-      (prog2
-	  (elmo-commit folder) ; Close session.
-	  (wl-folder-check-one-entity folder)
-	(elmo-commit folder))
+      (unless (elmo-pop3-get-session (elmo-folder-get-spec folder) 'if-exists)
+	;; Currently no main pop3 process.
+	(let ((elmo-network-session-name-prefix "BIFF-"))
+	  (wl-folder-check-one-entity folder)))
     (let ((elmo-network-session-name-prefix "BIFF-"))
       (wl-folder-check-one-entity folder))))
 
@@ -876,9 +875,10 @@ This function is imported from Emacs 20.7."
 			notify-minibuf))
 	    (let ((elmo-network-session-name-prefix "BIFF-"))
 	      (elmo-folder-diff-async folder)))
-	(wl-biff-notify (car (wl-biff-check-folder folder))
-			notify-minibuf)
-	(setq wl-biff-check-folders-running nil)))))
+	(unwind-protect
+	    (wl-biff-notify (car (wl-biff-check-folder folder))
+			    notify-minibuf)
+	  (setq wl-biff-check-folders-running nil))))))
 
 (if (and (fboundp 'regexp-opt)
 	 (not (featurep 'xemacs)))
