@@ -1,4 +1,4 @@
-;;; wl-vars.el -- Variable definitions for Wanderlust. -*-coding:euc-japan;-*-
+;;; wl-vars.el -- Variable definitions for Wanderlust.
 
 ;; Copyright (C) 1998,1999,2000,2001 Yuuichi Teranishi <teranisi@gohome.org>
 ;; Copyright (C) 1998,1999,2000,2001 Masahiro MURATA <muse@ba2.so-net.ne.jp>
@@ -32,6 +32,7 @@
 ;;
 
 (require 'elmo-vars)
+(require 'elmo-util)
 
 (if (module-installed-p 'custom)
     (require 'custom))
@@ -104,8 +105,6 @@
   (and wl-on-mule (or wl-on-xemacs
 		      (> emacs-major-version 19))))
 
-(require 'elmo-vars)
-
 (eval-when-compile
   (defun-maybe locate-data-directory (a)))
 
@@ -132,10 +131,14 @@
 (defvar wl-use-semi (module-installed-p 'mime-view) ; If nil, use tm.
   "*Use SEMI or not.")
 
-(defcustom wl-from (if (boundp 'user-mail-address)
-		       user-mail-address)
+(defcustom wl-from (and user-mail-address
+			(concat (and user-full-name
+				     (concat (elmo-address-quote-specials
+					      user-full-name)
+					     " "))
+				"<" user-mail-address ">"))
   "*From string used in draft."
-  :type 'string
+  :type  'string
   :group 'wl)
 
 (defcustom wl-user-mail-address-list nil
@@ -146,7 +149,7 @@ If you don't have multiple e-mail addresses, you don't have to set this."
   :type '(repeat string)
   :group 'wl)
 
-(defcustom wl-organization nil
+(defcustom wl-organization (getenv "ORGANIZATION")
   "Organization name."
   :type '(choice (const :tag "none" nil)
                  string)
@@ -473,7 +476,7 @@ reasons of system internal to accord facilities for the Emacs variants.")
   "A hook called when exit wanderlust.")
 (defvar wl-folder-suspend-hook nil
   "A hook called when suspend wanderlust.")
-(defvar wl-biff-notify-hook nil
+(defvar wl-biff-notify-hook '(ding)
   "A hook called when a biff-notification is invoked.")
 (defvar wl-biff-unnotify-hook nil
   "A hook called when a biff-notification is removed.")
@@ -679,6 +682,11 @@ Default is for 'followup-to-me'."
   :type '(string :tag "Base")
   :group 'wl)
 
+(defcustom wl-ldap-objectclass "person"
+  "*LDAP objectclass."
+  :type 'string
+  :group 'wl)
+
 (defcustom wl-use-ldap nil
   "*If non-nil, use LDAP for address completion."
   :type 'boolean
@@ -1119,6 +1127,17 @@ Set this if (system-name) does not return FQDN."
   :type 'boolean
   :group 'wl-pref)
 
+(defcustom wl-message-truncate-lines default-truncate-lines
+  "*Truncate lines in Message Buffer."
+  :type 'boolean
+  :group 'wl-pref)
+
+(defcustom wl-draft-truncate-lines default-truncate-lines
+  "*Truncate lines in Draft Buffer."
+  :type 'boolean
+  :group 'wl-draft
+  :group 'wl-pref)
+
 (defcustom wl-message-scroll-amount 5
   "*Scroll amount by SPC key."
   :type 'integer
@@ -1203,7 +1222,7 @@ with wl-highlight-folder-many-face."
 (defcustom wl-fcc nil
   "*Folder Carbon Copy."
   :type '(choice (const :tag "disable" nil)
-                 string)
+                 string function)
   :group 'wl-draft
   :group 'wl-pref)
 
@@ -1243,7 +1262,8 @@ with wl-highlight-folder-many-face."
 
 (defcustom wl-summary-width 80
   "*Set summary line width if non nil."
-  :type 'integer
+  :type '(choice (const :tag "Don't truncate" nil)
+		 integer)
   :group 'wl-summary
   :group 'wl-pref)
 
@@ -1449,12 +1469,24 @@ every intervals specified by wl-biff-check-interval."
   :type 'integer
   :group 'wl-highlight)
 
-(defcustom wl-biff-state-indicator-on "[]"
+(defcustom wl-biff-state-indicator-on (if (and (featurep 'xemacs)
+					       (not (featurep 'mule)))
+					  "[Mail]"
+					(decode-coding-string
+					 ;; Youbin mark
+					 (read "\"[\e$B\\\")\e(B]\"")
+					 (if (boundp 'MULE)
+					     '*iso-2022-jp*
+					   'iso-2022-jp)))
   "String used to show biff status ON."
   :type 'string
   :group 'wl-highlight)
 
-(defcustom wl-biff-state-indicator-off "[]"
+(defcustom wl-biff-state-indicator-off (if (and (featurep 'xemacs)
+						(not (featurep 'mule)))
+					   "[--]"
+					 ;; Japanese short hyphen
+					 "[$B!>(B]")
   "String used to show biff status OFF."
   :type 'string
   :group 'wl-highlight)
@@ -1478,7 +1510,7 @@ even if the value of this option is set to nil.  Here are some samples:
 			(sexp :tag "Other" :value title)))
   :group 'wl-highlight)
 
-(defcustom wl-interactive-send nil
+(defcustom wl-interactive-send t
   "*If non-nil, require your confirmation when sending draft message."
   :type 'boolean
   :group 'wl-pref)
@@ -2152,15 +2184,15 @@ a symbol `bitmap', `xbm' or `xpm' in order to force the image format."
 ;; Advanced thread view.
 (defvar wl-thread-indent-level 1
   "*Indent level for thread.")
-(defvar wl-thread-have-younger-brother-str ""
+(defvar wl-thread-have-younger-brother-str "$B(2(B"
   "*A string for thread branch line.  It should contain one character.")
-(defvar wl-thread-youngest-child-str       ""
+(defvar wl-thread-youngest-child-str       "$B(1(B"
   "*A string for thread branch line.  It should contain one character.")
-(defvar wl-thread-vertical-str             ""
+(defvar wl-thread-vertical-str             "$B(-(B"
   "*A string for thread branch line.  It should contain one character.")
-(defvar wl-thread-horizontal-str           ""
+(defvar wl-thread-horizontal-str           "$B(,(B"
   "*A string for thread branch line.  It should contain one character.")
-(defvar wl-thread-space-str                ""
+(defvar wl-thread-space-str                "$B!!(B"
   "*A string for thread branch line.  It should contain one character.")
 
 (defvar wl-highlight-thread-indent-string-regexp "[^[<]*"
