@@ -704,8 +704,7 @@ Entering Plugged mode calls the value of `wl-plugged-mode-hook'."
 (defun wl-check-environment (no-check-folder)
   (unless (featurep 'mime-setup)
     (require 'mime-setup))
-  (unless wl-from
-    (error "Please set `wl-from'"))
+  (unless wl-from (error "Please set `wl-from'"))
   ;; Message-ID
   (unless (string-match "[^.]\\.[^.]" (or wl-message-id-domain
 					  (if wl-local-domain
